part of forestvpn_api.api;



class WireguardApi {
  final ApiClient apiClient;

  WireguardApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Create new WireGuard profile with HTTP info returned
  ///
  /// 
  Future<Response> createProfileWithHttpInfo({ WireGuardProfileCreateRequest request }) async {
    Object postBody = request;

    // verify required params are set

    // create path and map variables
    String path = "/wg/profiles/".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["Bearer"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Create new WireGuard profile
  ///
  /// 
  Future<WireGuardProfile> createProfile({ WireGuardProfileCreateRequest request }) async {
    Response response = await createProfileWithHttpInfo( request: request );
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'WireGuardProfile') as WireGuardProfile;
    } else {
      return null;
    }
  }

  /// Delete WireGuarg profile with HTTP info returned
  ///
  /// 
  Future deleteProfileWithHttpInfo(String profileId) async {
    Object postBody;

    // verify required params are set
    if(profileId == null) {
     throw ApiException(400, "Missing required param: profileId");
    }

    // create path and map variables
    String path = "/wg/profiles/{profileId}/".replaceAll("{format}","json").replaceAll("{" + "profileId" + "}", profileId.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["Bearer"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'DELETE',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Delete WireGuarg profile
  ///
  /// 
  Future deleteProfile(String profileId) async {
    Response response = await deleteProfileWithHttpInfo(profileId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Retrieve WireGuarg profile with HTTP info returned
  ///
  /// 
  Future<Response> getProfileWithHttpInfo(String profileId) async {
    Object postBody;

    // verify required params are set
    if(profileId == null) {
     throw ApiException(400, "Missing required param: profileId");
    }

    // create path and map variables
    String path = "/wg/profiles/{profileId}/".replaceAll("{format}","json").replaceAll("{" + "profileId" + "}", profileId.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["Bearer"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Retrieve WireGuarg profile
  ///
  /// 
  Future<WireGuardProfile> getProfile(String profileId) async {
    Response response = await getProfileWithHttpInfo(profileId);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'WireGuardProfile') as WireGuardProfile;
    } else {
      return null;
    }
  }

  /// Retrieve list of WireGuard profiles with HTTP info returned
  ///
  /// 
  Future<Response> getProfilesWithHttpInfo() async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    String path = "/wg/profiles/".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["Bearer"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Retrieve list of WireGuard profiles
  ///
  /// 
  Future<List<WireGuardProfile>> getProfiles() async {
    Response response = await getProfilesWithHttpInfo();
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<WireGuardProfile>') as List).map((item) => item as WireGuardProfile).toList();
    } else {
      return null;
    }
  }

  /// Update profile with HTTP info returned
  ///
  /// 
  Future<Response> updateProfileWithHttpInfo(String profileId, WireGuardProfileUpdateRequest request) async {
    Object postBody = request;

    // verify required params are set
    if(profileId == null) {
     throw ApiException(400, "Missing required param: profileId");
    }
    if(request == null) {
     throw ApiException(400, "Missing required param: request");
    }

    // create path and map variables
    String path = "/wg/profiles/{profileId}/".replaceAll("{format}","json").replaceAll("{" + "profileId" + "}", profileId.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["Bearer"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'PATCH',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Update profile
  ///
  /// 
  Future<WireGuardProfile> updateProfile(String profileId, WireGuardProfileUpdateRequest request) async {
    Response response = await updateProfileWithHttpInfo(profileId, request);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'WireGuardProfile') as WireGuardProfile;
    } else {
      return null;
    }
  }

}
